import { aws_ec2 as ec2 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { LnBase } from '../common/ln-base';
export interface LnBucketProps {
    vpcId: ec2.IVpc;
    bucketId?: string;
    bucketName: string;
    versioned: boolean;
    enforceSSL: boolean;
}
/**
  * Creates a super S3 bucket.
  *
  * @example
  * import { LnBucket } from 'ln.aws.cdk.construct';
  *
  * //
  * // Get VpcId
  * //
  * const vpc = ec2.Vpc.fromLookup(stack, 'Vpc', { vpcId: 'vpc-093371ac27a8c4fe7' });
  * //
  * // Configure the Bucket Props
  * //
  * let props: LnBucketProps = {
  *   vpcId: vpc,
  *   bucketId: 'ln-aws-cdk-bucket',
  *   bucketName: 'ln-aws-cloudformation-bucket',
  *   versioned: true,
  * };
  * //
  * // Create Bucket
  * //
  * new LnBucket(stack, 'ln-aws-cloudformation-bucket', props);
  */
export declare class LnBucket extends LnBase {
    constructor(scope: Construct, id: string, props?: LnBucketProps);
}
